package fr.nabil.utils;

import fr.nabil.data.VRP;

import java.io.IOException;
import java.net.URI;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class FileReader {

    public static VRP readFile(URI fileUri) {
        try {
            List<String> lines = Files.readAllLines(Path.of(fileUri), StandardCharsets.UTF_8);

            return parseFile(lines);

        } catch (IOException e) {
            e.printStackTrace();
        }

        return null;
    }

    private static VRP parseFile(List<String> lines) {

        String name = "";
        String comment = "";
        String type = "";
        int dimension = 0;
        String weightType = "";
        int capacity = 0;

        Map<Integer, Pair<Integer, Integer>> nodeCoordSection = new HashMap<>();
        Map<Integer, Integer> demandeSection = new HashMap<>();

        for (String line : lines) {
            String[] words = line.split(" : ");

            switch (words[0].toLowerCase()) {

                case "name":
                    name = words[1];
                    break;
                case "comment":
                    comment = words[1];
                    break;
                case "type":
                    type = words[1];
                    break;
                case "dimension":
                    dimension = Integer.parseInt(words[1].trim());
                    break;
                case "edge_weight_type":
                    weightType = words[1];
                    break;
                case "capacity":
                    capacity = Integer.parseInt(words[1].trim());
                    break;
                default:
                    String[] reParsed = words[0].split(" ");
                    if (reParsed.length == 3) {
                        nodeCoordSection.put(Integer.parseInt(reParsed[0]), new Pair<>(Integer.parseInt(reParsed[1]), Integer.parseInt(reParsed[2])));
                    } else if (reParsed.length == 2) {
                        if (reParsed[0].equalsIgnoreCase("")) break;
                        demandeSection.put(Integer.parseInt(reParsed[0]), Integer.parseInt(reParsed[1]));
                    }
                    break;
            }
        }

        return new VRP(name, comment, type, dimension, weightType, capacity, nodeCoordSection, demandeSection);
    }

}
